@@ -115,6 +115,21 @@ void test_String()
     test_assert( "string convert to std::string", w, w2 );
 
     Py::String r2( "12345 789" );
+
+    // ord tests
+    Py::Char c3 = r2[2];
+    long v3 = c3.ord();
+    test_assert( "string ord value < 2^7", v3, long( 0x33 ) );
+
+    Py::Char c4( 0x10ff00 );
+    long v4 = c4.ord();
+    test_assert( "string ord value > 2^16", v4, long( 0x10ff00 ) );
+
+    Py::Char c5( 0xd5 );
+    long v5 = c5.ord();
+    test_assert( "string ord value < 2^8", v5, long( 0xd5 ) );
+
+    // convert tests
     Py::Char c6 = r2[5];
     test_assert( "string convert to std::string", c6, blank );
 
@@ -221,7 +236,6 @@ void test_long()
     py_long1 = cxx_long1;
     py_long2 = cxx_long2;
     py_long3 = cxx_long3;
-   
 
     // ------------------------------------------------------------
     test_assert( "long operator ==", cxx_long2 == cxx_long3, py_long2  == py_long3 );
@@ -288,6 +302,21 @@ void test_long()
     // ------------------------------------------------------------
     test_assert( "long operator long", cxx_long2, long( py_long2 ) );
     test_assert( "long operator int", int( cxx_long2 ), int( py_long2 ) );
+
+#ifdef HAVE_LONG_LONG
+    long long cxx_long_long11 = 1152921504616856976ll;
+    long long cxx_long_long12 = 6152921504616856976ll;
+    Py::Long py_long11( cxx_long_long11 );
+    Py::Long py_long12( 100 );
+
+    test_assert( "long long constructor 1", cxx_long_long11, py_long11.as_long_long() );
+    test_assert( "long long constructor 2", 1152921504616856976ll, py_long11.as_long_long() );
+    test_assert( "long long constructor 4", 100ll, py_long12.as_long_long() );
+
+    py_long12 = cxx_long_long12;
+
+    test_assert( "long long operator=", cxx_long_long12, py_long12.as_long_long() );
+#endif
 }
 
 void test_float()
@@ -406,7 +435,7 @@ void test_List()
     Py::List list1;
     Py::List list2;
 
-    test_assert( "list empty len()", list1.size(), static_cast<size_t>( 0 ) );
+    test_assert( "list empty len()", list1.size(), static_cast<Py_ssize_t>( 0 ) );
 
     list2.append( Py::String( "list2 index 0" ) );
     list2.append( Py::String( "list2 index 1" ) );
@@ -416,7 +445,7 @@ void test_List()
     list1.append( list2 );
     list1.append( Py::String( "world" ) );
 
-    test_assert( "list len()", static_cast<size_t>( 4 ), list1.size() );
+    test_assert( "list len()", static_cast<Py_ssize_t>( 4 ), list1.size() );
 
     test_assert( "list index[0]", Py::Long( 3 ), list1[0] );
     test_assert( "list index[1]", Py::Float( 6.0 ), list1[1] );
@@ -448,7 +477,7 @@ void test_List()
 
     Py::List list3;
     list3 = list1 + list2;
-    test_assert( "list operator+ count", static_cast<size_t>( 6 ), list3.size() );
+    test_assert( "list operator+ count", static_cast<Py_ssize_t>( 6 ), list3.size() );
 
     Py::Tuple tuple1( list1 );
     test_assert( "list construct from tuple", list1.size(), tuple1.size() );
@@ -488,7 +517,7 @@ void test_Tuple()
     {
         tuple3[0] = Py::Long( 1 ); // should fail, tuple has multiple references
     }
-    catch( Py::Exception &e )
+    catch( Py::BaseException &e )
     {
         e.clear();
         test_passed = true;
@@ -545,8 +574,8 @@ void test_Dict()
     test_assert( "dict index[std::string]", dict1[ std::string("one") ], Py::Long( 1 ) );
     test_assert( "dict index[Py::String]", dict1[ str1 ], Py::Long( 2 ) );
 
-    test_assert( "dict keys()", dict1.keys().size(), static_cast<size_t>( 3 ) );
-    test_assert( "dict values()", dict1.values().size(), static_cast<size_t>( 3 ) );
+    test_assert( "dict keys()", dict1.keys().size(), static_cast<Py_ssize_t>( 3 ) );
+    test_assert( "dict values()", dict1.values().size(), static_cast<Py_ssize_t>( 3 ) );
 
     Py::Dict::iterator it1 = dict1.begin();
     test_assert( "dict iterator not end != [0]", true, it1 != dict1.end() );
@@ -558,7 +587,7 @@ void test_Dict()
     test_assert( "dict iterator not end != [2]", true, it1 != dict1.end() );
     test_assert( "dict iterator not end == [2]", false, it1 == dict1.end() );
     ++it1;
-    
+
     Py::Dict::iterator it2 = dict1.end();
     bool x = it1 != it2;
     test_assert( "x", false, x );
@@ -575,7 +604,7 @@ void test_Dict()
 
     Py::Dict dict2 = dict1;
     dict2.clear();
-    test_assert( "dict clear()", dict2.keys().length(), static_cast<size_t>( 0 ) );
+    test_assert( "dict clear()", dict2.keys().length(), Py_ssize_t( 0 ) );
 
     const Py::Dict c;
     for (Py::Dict::const_iterator it = c.begin(); it != c.end(); ++it)
@@ -750,7 +779,7 @@ private:
             a.verify_length(0);
             std::cout << "I see that you refuse to give me any work to do." << std::endl;
         }
-        catch (Py::Exception& e)
+        catch (Py::BaseException& e)
         {
             e.clear();
             std::cout << "I will now add up your elements, oh great one." << std::endl;
@@ -767,7 +796,7 @@ private:
         return f;
     }
 
-    Py::Object ex_test( const Py::Tuple &args )
+    Py::Object ex_test( const Py::Tuple &/*args*/ )
     {
         debug_check_ref_queue();
 
@@ -784,8 +813,8 @@ private:
             e.clear();
 
             std::cout << "PASSED: Correctly caught " << Py::type(e) << std::endl;
-            std::cout << "PASSED:   Py::Exception value: " << Py::value(e) << std::endl;
-            std::cout << "PASSED:   Py::Exception traceback: " << Py::trace(e) << std::endl;
+            std::cout << "PASSED:   Py::BaseException value: " << Py::value(e) << std::endl;
+            std::cout << "PASSED:   Py::BaseException traceback: " << Py::trace(e) << std::endl;
         }
 
         try
