@@ -174,7 +174,7 @@ bool FunctionArguments::hasArg( const char *arg_name )
     if( !found_arg_name )
     {
         std::string msg = m_function_name;
-        msg += "() coding error: function does not have a arg called '";
+        msg += "() coding error: function does not have an arg called '";
         msg += std_arg_name;
         msg += "'";
         throw Py::RuntimeError( msg );
@@ -183,6 +183,16 @@ bool FunctionArguments::hasArg( const char *arg_name )
     return m_checked_args.hasKey( arg_name );
 }
 
+bool FunctionArguments::hasArgNotNone( const char *arg_name )
+{
+    if( !hasArg( arg_name ) )
+    {
+        return false;
+    }
+    Py::Object arg = m_checked_args[ arg_name ];
+    return !arg.isNone();
+}
+
 Py::Object FunctionArguments::getArg( const char *arg_name )
 {
     if( !hasArg( arg_name ) )
@@ -376,7 +386,7 @@ svn_depth_t FunctionArguments::getDepth
 
     if( hasArg( depth_name ) )
     {
-        return getDepth( depth_name );
+        return getDepth( depth_name, default_value );
     }
 
     return default_value;
@@ -390,7 +400,16 @@ svn_depth_t FunctionArguments::getDepth
 {
     if( hasArg( depth_name ) )
     {
-        return getDepth( depth_name );
+        Py::Object value( getArg( depth_name ) );
+        if( value.isNone() )
+        {
+            return default_value;
+        }
+        else
+        {
+            Py::ExtensionObject< pysvn_enum_value<svn_depth_t> > py_kind( value );
+            return svn_depth_t( py_kind.extensionObject()->m_value );
+        }
     }
 
     return default_value;
