@@ -50,6 +50,7 @@ static void init_py_names()
     py_name_has_props = new Py::String( name_has_props );
     py_name_kind = new Py::String( name_kind );
     py_name_last_author = new Py::String( name_last_author );
+    py_name_lock = new Py::String( name_lock );
     py_name_name = new Py::String( name_name );
     py_name_node_kind = new Py::String( name_node_kind );
     py_name_path = new Py::String( name_path );
@@ -63,6 +64,9 @@ static void init_py_names()
 }
 
 //--------------------------------------------------------------------------------
+#if defined( PYSVN_HAS_CLIENT_STATUS_T )
+std::string name_wrapper_status2("PysvnStatus2");
+#endif
 std::string name_wrapper_status("PysvnStatus");
 std::string name_wrapper_entry("PysvnEntry");
 std::string name_wrapper_info("PysvnInfo");
@@ -73,6 +77,7 @@ std::string name_wrapper_log_changed_path("PysvnLogChangedPath");
 std::string name_wrapper_dirent("PysvnDirent");
 std::string name_wrapper_wc_info("PysvnWcInfo");
 std::string name_wrapper_diff_summary("PysvnDiffSummary");
+std::string name_wrapper_commit_info("PysvnCommitInfo");
 
 pysvn_client::pysvn_client
     (
@@ -85,6 +90,9 @@ pysvn_client::pysvn_client
 , m_context( config_dir )
 , m_exception_style( 0 )
 , m_commit_info_style( 0 )
+#if defined( PYSVN_HAS_CLIENT_STATUS_T )
+, m_wrapper_status2( result_wrappers, name_wrapper_status2 )
+#endif
 , m_wrapper_status( result_wrappers, name_wrapper_status )
 , m_wrapper_entry( result_wrappers, name_wrapper_entry )
 , m_wrapper_info( result_wrappers, name_wrapper_info )
@@ -95,6 +103,7 @@ pysvn_client::pysvn_client
 , m_wrapper_dirent( result_wrappers, name_wrapper_dirent )
 , m_wrapper_wc_info( result_wrappers, name_wrapper_wc_info )
 , m_wrapper_diff_summary( result_wrappers, name_wrapper_diff_summary )
+, m_wrapper_commit_info( result_wrappers, name_wrapper_commit_info )
 {
     init_py_names();
 }
@@ -249,13 +258,13 @@ int pysvn_client::setattr( const char *_name, const Py::Object &value )
     else if( name == name_commit_info_style )
     {
         Py::Int style( value );
-        if( style == 0l || style == 1l )
+        if( style == 0l || style == 1l || style == 2l )
         {
             m_commit_info_style = style;
         }
             else
         {
-            throw Py::AttributeError( "commit_info_style value must be 0 or 1" );
+            throw Py::AttributeError( "commit_info_style value must be 0, 1 or 2" );
         }
     }
 
@@ -726,6 +735,18 @@ Py::Object pysvn_client::cmd_root_url_from_path( const Py::Tuple& a_args, const
         PythonAllowThreads permission( m_context );
 
         // known to call back into pysvn
+#if defined( PYSVN_HAS_CLIENT_GET_REPOS_ROOT )
+        const char *repos_uuid = NULL;
+        svn_error_t *error = svn_client_get_repos_root
+            (
+            &root_url,
+            &repos_uuid,
+            norm_path.c_str(),
+            m_context,
+            pool,
+            pool
+            );
+#else
         svn_error_t *error = svn_client_root_url_from_path
             (
             &root_url,
@@ -733,6 +754,7 @@ Py::Object pysvn_client::cmd_root_url_from_path( const Py::Tuple& a_args, const
             m_context,
             pool
             );
+#endif
         if( error != NULL )
             throw SvnException( error );
     }
@@ -830,10 +852,13 @@ void pysvn_client::init_type()
     behaviors().supportSetattr();
 
     add_keyword_method("add", &pysvn_client::cmd_add, pysvn_client_add_doc );
-#ifdef PYSVN_HAS_CLIENT_ADD_TO_CHANGELIST
+#if defined( PYSVN_HAS_CLIENT_ADD_TO_CHANGELIST )
     add_keyword_method("add_to_changelist", &pysvn_client::cmd_add_to_changelist, pysvn_client_add_to_changelist_doc );
 #endif
     add_keyword_method("annotate", &pysvn_client::cmd_annotate, pysvn_client_annotate_doc );
+#if defined( PYSVN_HAS_CLIENT_ANNOTATE5 )
+    add_keyword_method("annotate2", &pysvn_client::cmd_annotate2, pysvn_client_annotate2_doc );
+#endif
     add_keyword_method("cat", &pysvn_client::cmd_cat, pysvn_client_cat_doc );
     add_keyword_method("checkin", &pysvn_client::cmd_checkin, pysvn_client_checkin_doc );
     add_keyword_method("checkout", &pysvn_client::cmd_checkout, pysvn_client_checkout_doc );
@@ -851,7 +876,7 @@ void pysvn_client::init_type()
     add_keyword_method("diff_summarize_peg", &pysvn_client::cmd_diff_summarize_peg, pysvn_client_diff_summarize_peg_doc );
 #endif
     add_keyword_method("export", &pysvn_client::cmd_export, pysvn_client_export_doc );
-#ifdef PYSVN_HAS_CLIENT_GET_CHANGELIST
+#if defined( PYSVN_HAS_CLIENT_GET_CHANGELIST )
     add_keyword_method("get_changelist", &pysvn_client::cmd_get_changelist, pysvn_client_get_changelist_doc );
 #endif
 #if defined( PYSVN_HAS_WC_ADM_DIR )
@@ -902,9 +927,17 @@ void pysvn_client::init_type()
     add_keyword_method("propget", &pysvn_client::cmd_propget, pysvn_client_propget_doc );
     add_keyword_method("proplist", &pysvn_client::cmd_proplist, pysvn_client_proplist_doc );
     add_keyword_method("propset", &pysvn_client::cmd_propset, pysvn_client_propset_doc );
+#if defined( PYSVN_HAS_CLIENT_PROPSET_LOCAL )
+    add_keyword_method("propdel_local", &pysvn_client::cmd_propdel_local, pysvn_client_propdel_local_doc );
+    add_keyword_method("propset_local", &pysvn_client::cmd_propset_local, pysvn_client_propset_local_doc );
+#endif
+#if defined( PYSVN_HAS_CLIENT_PROPSET_REMOTE )
+    add_keyword_method("propdel_remote", &pysvn_client::cmd_propdel_remote, pysvn_client_propdel_remote_doc );
+    add_keyword_method("propset_remote", &pysvn_client::cmd_propset_remote, pysvn_client_propset_remote_doc );
+#endif
     add_keyword_method("relocate", &pysvn_client::cmd_relocate, pysvn_client_relocate_doc );
     add_keyword_method("remove", &pysvn_client::cmd_remove, pysvn_client_remove_doc );
-#ifdef PYSVN_HAS_CLIENT_REMOVE_FROM_CHANGELISTS
+#if defined( PYSVN_HAS_CLIENT_REMOVE_FROM_CHANGELISTS )
     add_keyword_method("remove_from_changelists", &pysvn_client::cmd_remove_from_changelists, pysvn_client_remove_from_changelists_doc );
 #endif
     add_keyword_method("resolved", &pysvn_client::cmd_resolved, pysvn_client_resolved_doc );
@@ -925,6 +958,9 @@ void pysvn_client::init_type()
     add_keyword_method("set_default_username", &pysvn_client::set_default_username, pysvn_client_set_default_username_doc );
     add_keyword_method("set_interactive", &pysvn_client::set_interactive, pysvn_client_set_interactive_doc );
     add_keyword_method("set_store_passwords", &pysvn_client::set_store_passwords, pysvn_client_set_store_passwords_doc );
+#if defined( PYSVN_HAS_CLIENT_STATUS5 )
+    add_keyword_method("status2", &pysvn_client::cmd_status2, pysvn_client_status2_doc );
+#endif
     add_keyword_method("status", &pysvn_client::cmd_status, pysvn_client_status_doc );
     add_keyword_method("switch", &pysvn_client::cmd_switch, pysvn_client_switch_doc );
 #if defined( PYSVN_HAS_CLIENT_LOCK )
@@ -934,4 +970,7 @@ void pysvn_client::init_type()
     add_keyword_method("upgrade", &pysvn_client::cmd_upgrade, pysvn_client_upgrade_doc );
 #endif
     add_keyword_method("update", &pysvn_client::cmd_update, pysvn_client_update_doc );
+#if defined( PYSVN_HAS_CLIENT_VACUUM )
+    add_keyword_method("vacuum", &pysvn_client::cmd_vacuum, pysvn_client_vacuum_doc );
+#endif
 }
