@@ -35,6 +35,13 @@ Py::Object pysvn_client::cmd_checkin( const Py::Tuple &a_args, const Py::Dict &a
     { false, name_keep_changelist },
     { false, name_changelists },
     { false, name_revprops },
+#endif
+#if defined( PYSVN_HAS_CLIENT_COMMIT5 )
+    { false, name_commit_as_operations },
+#endif
+#if defined( PYSVN_HAS_CLIENT_COMMIT6 )
+    { false, name_include_file_externals },
+    { false, name_include_dir_externals },
 #endif
     { false, NULL }
     };
@@ -42,7 +49,11 @@ Py::Object pysvn_client::cmd_checkin( const Py::Tuple &a_args, const Py::Dict &a
     args.check();
 
     SvnPool pool( m_context );
+#if defined( PYSVN_HAS_CLIENT_COMMIT5 )
+    CommitInfoResult commit_info( pool );
+#else
     pysvn_commit_info_t *commit_info = NULL;
+#endif
 
     apr_array_header_t *targets = targetsFromStringOrList( args.getArg( name_path ), pool );
 
@@ -50,7 +61,6 @@ Py::Object pysvn_client::cmd_checkin( const Py::Tuple &a_args, const Py::Dict &a
     try
     {
         type_error_message = "expecting string for message (arg 2)";
-
         std::string message( args.getUtf8String( name_log_message ) );
 
 #ifndef PYSVN_HAS_CLIENT_COMMIT4
@@ -74,15 +84,26 @@ Py::Object pysvn_client::cmd_checkin( const Py::Tuple &a_args, const Py::Dict &a
             changelists = arrayOfStringsFromListOfStrings( args.getArg( name_changelists ), pool );
         }
 
-    apr_hash_t *revprops = NULL;
-    if( args.hasArg( name_revprops ) )
-    {
-        Py::Object py_revprop = args.getArg( name_revprops );
-        if( !py_revprop.isNone() )
+        apr_hash_t *revprops = NULL;
+        if( args.hasArg( name_revprops ) )
         {
-            revprops = hashOfStringsFromDictOfStrings( py_revprop, pool );
+            Py::Object py_revprop = args.getArg( name_revprops );
+            if( !py_revprop.isNone() )
+            {
+                revprops = hashOfStringsFromDictOfStrings( py_revprop, pool );
+            }
         }
-    }
+#endif
+#if defined( PYSVN_HAS_CLIENT_COMMIT5 )
+        type_error_message = "expecting boolean for commit_as_operations keyword arg";
+        bool commit_as_operations = args.getBoolean( name_commit_as_operations, false );
+#endif
+#if defined( PYSVN_HAS_CLIENT_COMMIT6 )
+        type_error_message = "expecting boolean for include_file_externals keyword arg";
+        bool include_file_externals = args.getBoolean( name_include_file_externals, false );
+
+        type_error_message = "expecting boolean for include_dir_externals keyword arg";
+        bool include_dir_externals = args.getBoolean( name_include_dir_externals, false );
 #endif
 
         try
@@ -93,7 +114,39 @@ Py::Object pysvn_client::cmd_checkin( const Py::Tuple &a_args, const Py::Dict &a
 
             m_context.setLogMessage( message );
 
-#if defined( PYSVN_HAS_CLIENT_COMMIT4 )
+#if defined( PYSVN_HAS_CLIENT_COMMIT6 )
+            svn_error_t *error = svn_client_commit6
+                (
+                targets,
+                depth,
+                keep_locks,
+                keep_changelist,
+                commit_as_operations,
+                include_file_externals,
+                include_dir_externals,
+                changelists,
+                revprops,
+                commit_info.callback(),
+                commit_info.baton(),
+                m_context,
+                pool
+                );
+#elif defined( PYSVN_HAS_CLIENT_COMMIT5 )
+            svn_error_t *error = svn_client_commit5
+                (
+                targets,
+                depth,
+                keep_locks,
+                keep_changelist,
+                commit_as_operations,
+                changelists,
+                revprops,
+                commit_info.callback(),
+                commit_info.baton(),
+                m_context,
+                pool
+                );
+#elif defined( PYSVN_HAS_CLIENT_COMMIT4 )
             svn_error_t *error = svn_client_commit4
                 (
                 &commit_info,
@@ -153,7 +206,11 @@ Py::Object pysvn_client::cmd_checkin( const Py::Tuple &a_args, const Py::Dict &a
         throw Py::TypeError( type_error_message );
     }
 
+#if defined( PYSVN_HAS_CLIENT_COMMIT5 )
+    return toObject( commit_info, m_wrapper_commit_info, m_commit_info_style );
+#else
     return toObject( commit_info, m_commit_info_style );
+#endif
 }
 
 Py::Object pysvn_client::cmd_checkout( const Py::Tuple &a_args, const Py::Dict &a_kws )
@@ -270,6 +327,13 @@ Py::Object pysvn_client::cmd_cleanup( const Py::Tuple &a_args, const Py::Dict &a
     static argument_description args_desc[] =
     {
     { true,  name_path },
+#if defined( PYSVN_HAS_CLIENT_CLEANUP2 )
+    { false, name_break_locks },
+    { false, name_fix_recorded_timestamps },
+    { false, name_clear_dav_cache },
+    { false, name_vacuum_pristines },
+    { false, name_include_externals },
+#endif
     { false, NULL }
     };
     FunctionArguments args( "cleanup", args_desc, a_args, a_kws );
@@ -277,6 +341,14 @@ Py::Object pysvn_client::cmd_cleanup( const Py::Tuple &a_args, const Py::Dict &a
 
     std::string path( args.getUtf8String( name_path ) );
 
+#if defined( PYSVN_HAS_CLIENT_CLEANUP2 )
+    bool break_locks = args.getBoolean( name_break_locks, true );
+    bool fix_recorded_timestamps = args.getBoolean( name_fix_recorded_timestamps, true );
+    bool clear_dav_cache = args.getBoolean( name_clear_dav_cache, true );
+    bool vacuum_pristines = args.getBoolean( name_vacuum_pristines, true );
+    bool include_externals = args.getBoolean( name_include_externals, false );
+#endif
+
     SvnPool pool( m_context );
 
     try
@@ -287,7 +359,97 @@ Py::Object pysvn_client::cmd_cleanup( const Py::Tuple &a_args, const Py::Dict &a
 
         PythonAllowThreads permission( m_context );
 
-        svn_error_t * error = svn_client_cleanup( norm_path.c_str(), m_context, pool);
+#if defined( PYSVN_HAS_CLIENT_CLEANUP2 )
+        const char *abspath = NULL;
+        svn_error_t *error = svn_dirent_get_absolute( &abspath, norm_path.c_str(), pool );
+
+        if( error == NULL )
+        {
+            error = svn_client_cleanup2
+                (
+                abspath,
+                break_locks,
+                fix_recorded_timestamps,
+                clear_dav_cache,
+                vacuum_pristines,
+                include_externals,
+                m_context,
+                pool
+                );
+        }
+#else
+        svn_error_t * error = svn_client_cleanup
+            (
+            norm_path.c_str(),
+            m_context,
+            pool
+            );
+#endif
+        permission.allowThisThread();
+        if( error != NULL )
+            throw SvnException( error );
+    }
+    catch( SvnException &e )
+    {
+        // use callback error over ClientException
+        m_context.checkForError( m_module.client_error );
+
+        throw_client_error( e );
+    }
+
+    return Py::None();
+}
+#if defined( PYSVN_HAS_CLIENT_VACUUM )
+Py::Object pysvn_client::cmd_vacuum( const Py::Tuple &a_args, const Py::Dict &a_kws )
+{
+    static argument_description args_desc[] =
+    {
+    { true,  name_path },
+    { false, name_remove_unversioned_items },
+    { false, name_remove_ignored_items },
+    { false, name_fix_recorded_timestamps },
+    { false, name_vacuum_pristines },
+    { false, name_include_externals },
+    { false, NULL }
+    };
+    FunctionArguments args( "vacuum", args_desc, a_args, a_kws );
+    args.check();
+
+    std::string path( args.getUtf8String( name_path ) );
+
+    bool remove_unversioned_items = args.getBoolean( name_remove_unversioned_items, false );
+    bool remove_ignored_items = args.getBoolean( name_remove_ignored_items, false );
+    bool fix_recorded_timestamps = args.getBoolean( name_fix_recorded_timestamps, true );
+    bool vacuum_pristines = args.getBoolean( name_vacuum_pristines, true );
+    bool include_externals = args.getBoolean( name_include_externals, false );
+
+    SvnPool pool( m_context );
+
+    try
+    {
+        std::string norm_path( svnNormalisedIfPath( path, pool ) );
+
+        checkThreadPermission();
+
+        PythonAllowThreads permission( m_context );
+
+        const char *abspath = NULL;
+        svn_error_t *error = svn_dirent_get_absolute( &abspath, norm_path.c_str(), pool );
+
+        if( error == NULL )
+        {
+            error = svn_client_vacuum
+                (
+                abspath,
+                remove_unversioned_items,
+                remove_ignored_items,
+                fix_recorded_timestamps,
+                vacuum_pristines,
+                include_externals,
+                m_context,
+                pool
+                );
+        }
 
         permission.allowThisThread();
         if( error != NULL )
@@ -303,6 +465,7 @@ Py::Object pysvn_client::cmd_cleanup( const Py::Tuple &a_args, const Py::Dict &a
 
     return Py::None();
 }
+#endif
 
 Py::Object pysvn_client::cmd_resolved( const Py::Tuple &a_args, const Py::Dict &a_kws )
 {
@@ -384,6 +547,10 @@ Py::Object pysvn_client::cmd_update( const Py::Tuple &a_args, const Py::Dict &a_
     { false, name_depth },
     { false, name_depth_is_sticky },
     { false, name_allow_unver_obstructions },
+#endif
+#if defined( PYSVN_HAS_CLIENT_UPDATE4 )
+    { false, name_adds_as_modification },
+    { false, name_make_parents },
 #endif
     { false, NULL }
     };
@@ -405,6 +572,11 @@ Py::Object pysvn_client::cmd_update( const Py::Tuple &a_args, const Py::Dict &a_
 #if defined( PYSVN_HAS_CLIENT_UPDATE2 )
     bool ignore_externals = args.getBoolean( name_ignore_externals, false );
 #endif
+#if defined( PYSVN_HAS_CLIENT_UPDATE4 )
+    bool adds_as_modification = args.getBoolean( name_adds_as_modification, false );
+    bool make_parents = args.getBoolean( name_make_parents, false );
+#endif
+
     apr_array_header_t *result_revs = NULL;
 
     try
@@ -413,7 +585,22 @@ Py::Object pysvn_client::cmd_update( const Py::Tuple &a_args, const Py::Dict &a_
 
         PythonAllowThreads permission( m_context );
 
-#if defined( PYSVN_HAS_CLIENT_UPDATE3 )
+#if defined( PYSVN_HAS_CLIENT_UPDATE4 )
+        svn_error_t *error = svn_client_update4
+            (
+            &result_revs,
+            targets,
+            &revision,
+            depth,
+            depth_is_sticky,
+            ignore_externals,
+            allow_unver_obstructions,
+            adds_as_modification,
+            make_parents,
+            m_context,
+            pool
+            );
+#elif defined( PYSVN_HAS_CLIENT_UPDATE3 )
         svn_error_t *error = svn_client_update3
             (
             &result_revs,
