@@ -8,7 +8,7 @@
 // ====================================================================
 //
 //
-//  pysvn_client_cmd_diff.cpp
+//  pysvn_client_cmd_export.cpp
 //
 #if defined( _MSC_VER )
 // disable warning C4786: symbol greater than 255 character,
@@ -104,6 +104,7 @@ Py::Object pysvn_client::cmd_export( const Py::Tuple &a_args, const Py::Dict &a_
     try
     {
         std::string norm_src_path( svnNormalisedIfPath( src_path, pool ) );
+        std::string norm_dest_path( svnNormalisedIfPath( dest_path, pool ) );
 
         checkThreadPermission();
 
@@ -114,7 +115,7 @@ Py::Object pysvn_client::cmd_export( const Py::Tuple &a_args, const Py::Dict &a_
             (
             &revnum,
             norm_src_path.c_str(),
-            dest_path.c_str(),
+            norm_dest_path.c_str(),
             &peg_revision,
             &revision,
             force,
@@ -209,6 +210,9 @@ Py::Object pysvn_client::cmd_import( const Py::Tuple &a_args, const Py::Dict &a_
     { false, name_depth },
     { false, name_ignore_unknown_node_types },
     { false, name_revprops },
+#endif
+#if defined( PYSVN_HAS_CLIENT_IMPORT5 )
+    { false, name_autoprops },
 #endif
     { false, NULL }
     };
@@ -241,11 +245,20 @@ Py::Object pysvn_client::cmd_import( const Py::Tuple &a_args, const Py::Dict &a_
     bool ignore = args.getBoolean( name_ignore, false );
 #endif
 
+#if defined( PYSVN_HAS_CLIENT_IMPORT5 )
+    bool autoprops = args.getBoolean( name_autoprops, true );
+#endif
+
+#if defined( PYSVN_HAS_CLIENT_IMPORT4 )
+    CommitInfoResult commit_info( pool );
+#else
     pysvn_commit_info_t *commit_info = NULL;
+#endif
 
     try
     {
         std::string norm_path( svnNormalisedIfPath( path, pool ) );
+        std::string norm_url( svnNormalisedUrl( url, pool ) );
 
         checkThreadPermission();
 
@@ -253,12 +266,43 @@ Py::Object pysvn_client::cmd_import( const Py::Tuple &a_args, const Py::Dict &a_
 
         m_context.setLogMessage( message.c_str() );
 
-#if defined( PYSVN_HAS_CLIENT_IMPORT3 )
+#if defined( PYSVN_HAS_CLIENT_IMPORT5 )
+        svn_error_t *error = svn_client_import5
+            (
+            norm_path.c_str(),
+            norm_url.c_str(),
+            depth,
+            !ignore,
+            !autoprops,
+            ignore_unknown_node_types,
+            revprops,
+            NULL,       // filter_callback
+            NULL,       // filter_baton
+            commit_info.callback(),
+            commit_info.baton(),
+            m_context,
+            pool
+            );
+#elif defined( PYSVN_HAS_CLIENT_IMPORT4 )
+        svn_error_t *error = svn_client_import4
+            (
+            norm_path.c_str(),
+            norm_url.c_str(),
+            depth,
+            !ignore,
+            ignore_unknown_node_types,
+            revprops,
+            commit_info.callback(),
+            commit_info.baton(),
+            m_context,
+            pool
+            );
+#elif defined( PYSVN_HAS_CLIENT_IMPORT3 )
         svn_error_t *error = svn_client_import3
             (
             &commit_info,       // changed type
             norm_path.c_str(),
-            url.c_str(),
+            norm_url.c_str(),
             depth,
             !ignore,
             ignore_unknown_node_types,
@@ -300,5 +344,9 @@ Py::Object pysvn_client::cmd_import( const Py::Tuple &a_args, const Py::Dict &a_
         throw_client_error( e );
     }
 
+#if defined( PYSVN_HAS_CLIENT_IMPORT4 )
+    return toObject( commit_info, m_wrapper_commit_info, m_commit_info_style );
+#else
     return toObject( commit_info, m_commit_info_style );
+#endif
 }
