@@ -25,6 +25,9 @@ Py::Object pysvn_client::cmd_revpropdel( const Py::Tuple &a_args, const Py::Dict
     {
     { true,  name_prop_name },
     { true,  name_url },
+#if defined( PYSVN_HAS_CLIENT_REVPROP_SET2 )
+    { false, name_original_prop_value },
+#endif
     { false, name_revision },
     { false, name_force },
     { false, NULL }
@@ -32,9 +35,45 @@ Py::Object pysvn_client::cmd_revpropdel( const Py::Tuple &a_args, const Py::Dict
     FunctionArguments args( "revpropdel", args_desc, a_args, a_kws );
     args.check();
 
-    std::string propname( args.getUtf8String( name_prop_name ) );
-    std::string path( args.getUtf8String( name_url ) );
+    return common_revpropset( args, false );
+}
 
+Py::Object pysvn_client::cmd_revpropset( const Py::Tuple &a_args, const Py::Dict &a_kws )
+{
+    static argument_description args_desc[] =
+    {
+    { true,  name_prop_name },
+    { true,  name_prop_value },
+    { true,  name_url },
+#if defined( PYSVN_HAS_CLIENT_REVPROP_SET2 )
+    { false, name_original_prop_value },
+#endif
+    { false, name_revision },
+    { false, name_force },
+    { false, NULL }
+    };
+    FunctionArguments args( "revpropset", args_desc, a_args, a_kws );
+    args.check();
+
+    return common_revpropset( args, true );
+}
+
+Py::Object pysvn_client::common_revpropset( FunctionArguments &args, bool is_set )
+{
+    std::string propname( args.getUtf8String( name_prop_name ) );
+    std::string propval;
+    if( is_set )
+    {
+        propval = args.getUtf8String( name_prop_value );
+    }
+    std::string original_propval;
+    bool has_original_propval = args.hasArgNotNone( name_original_prop_value );
+    if( has_original_propval )
+    {
+        original_propval = args.getUtf8String( name_original_prop_value );
+    }
+
+    std::string path( args.getUtf8String( name_url ) );
     svn_opt_revision_t revision = args.getRevision( name_revision, svn_opt_revision_head );
 
     bool force = args.getBoolean( name_force, false );
@@ -50,10 +89,24 @@ Py::Object pysvn_client::cmd_revpropdel( const Py::Tuple &a_args, const Py::Dict
 
         PythonAllowThreads permission( m_context );
 
-        svn_error_t *error = svn_client_revprop_set
+        const svn_string_t *svn_propval = NULL;
+        if( is_set )
+        {
+            svn_propval = svn_string_ncreate( propval.c_str(), propval.size(), pool );
+        }
+
+#if defined( PYSVN_HAS_CLIENT_REVPROP_SET2 )
+        const svn_string_t *svn_original_propval = NULL;
+        if( has_original_propval )
+        {
+            svn_original_propval = svn_string_ncreate( original_propval.c_str(), original_propval.size(), pool );
+        }
+
+        svn_error_t *error = svn_client_revprop_set2
             (
             propname.c_str(),
-            NULL,            // value = NULL
+            svn_propval,
+            svn_original_propval,
             norm_path.c_str(),
             &revision,
             &revnum,
@@ -61,6 +114,19 @@ Py::Object pysvn_client::cmd_revpropdel( const Py::Tuple &a_args, const Py::Dict
             m_context,
             pool
             );
+#else
+        svn_error_t *error = svn_client_revprop_set
+            (
+            propname.c_str(),
+            svn_propval,
+            norm_path.c_str(),
+            &revision,
+            &revnum,
+            force,
+            m_context,
+            pool
+            );
+#endif
         permission.allowThisThread();
         if( error != NULL )
             throw SvnException( error );
@@ -197,62 +263,3 @@ Py::Object pysvn_client::cmd_revproplist( const Py::Tuple &a_args, const Py::Dic
 
     return result;
 }
-
-Py::Object pysvn_client::cmd_revpropset( const Py::Tuple &a_args, const Py::Dict &a_kws )
-{
-    static argument_description args_desc[] =
-    {
-    { true,  name_prop_name },
-    { true,  name_prop_value },
-    { true,  name_url },
-    { false, name_revision },
-    { false, name_force },
-    { false, NULL }
-    };
-    FunctionArguments args( "revpropset", args_desc, a_args, a_kws );
-    args.check();
-
-    std::string propname( args.getUtf8String( name_prop_name ) );
-    std::string propval( args.getUtf8String( name_prop_value ) );
-    std::string path( args.getUtf8String( name_url ) );
-    svn_opt_revision_t revision = args.getRevision( name_revision, svn_opt_revision_head );
-
-    bool force = args.getBoolean( name_force, false );
-
-    SvnPool pool( m_context );
-
-    svn_revnum_t revnum = 0;
-    try
-    {
-        std::string norm_path( svnNormalisedIfPath( path, pool ) );
-
-        checkThreadPermission();
-
-        PythonAllowThreads permission( m_context );
-
-        const svn_string_t *svn_propval = svn_string_ncreate( propval.c_str(), propval.size(), pool );
-        svn_error_t *error = svn_client_revprop_set
-            (
-            propname.c_str(),
-            svn_propval,
-            norm_path.c_str(),
-            &revision,
-            &revnum,
-            force,
-            m_context,
-            pool
-            );
-        permission.allowThisThread();
-        if( error != NULL )
-            throw SvnException( error );
-    }
-    catch( SvnException &e )
-    {
-        // use callback error over ClientException
-        m_context.checkForError( m_module.client_error );
-
-        throw_client_error( e );
-    }
-
-    return Py::asObject( new pysvn_revision( svn_opt_revision_number, 0, revnum ) );
-}
