@@ -12,17 +12,15 @@
 
 #include "CXX/Objects.hxx"
 
-#ifndef PYCXX_MAKEVERSION
-#error PyCXX version 5.3.5 is required
-#endif
-
-#if PYCXX_VERSION < PYCXX_MAKEVERSION( 6, 2, 4 )
+#if !defined( PYCXX_MAKEVERSION ) || PYCXX_VERSION < PYCXX_MAKEVERSION( 6, 2, 4 )
 #error PyCXX version 6.2.4 or later required
 #endif
 
 #include <svn_version.h>
 #include <svn_client.h>
 #include <svn_dirent_uri.h>
+#include <svn_path.h>
+#include <svn_props.h>
 #include <svn_fs.h>
 #include <svn_repos.h>
 #include <apr_xlate.h>
@@ -161,6 +159,7 @@
 #define PYSVN_HAS_CLIENT_COPY5
 #define PYSVN_HAS_IO_OPEN_UNIQUE_FILE3
 #define PYSVN_HAS_CLIENT_LOG5
+#define PYSVN_HAS_CLIENT_REVPROP_SET2 1
 #define PYSVN_HAS_CLIENT_STATUS4
 #define PYSVN_HAS_AUTH_GET_SIMPLE_PROVIDER2
 #define PYSVN_HAS_AUTH_GET_SSL_CLIENT_CERT_PW_FILE_PROVIDER2
@@ -173,15 +172,16 @@
 // SVN 1.7 or later
 #if (SVN_VER_MAJOR == 1 && SVN_VER_MINOR >= 7) || SVN_VER_MAJOR > 1
 #define PYSVN_HAS_SVN_1_7
+#define PYSVN_HAS_COMMIT_CALLBACK2_T qqq
 #define PYSNV_HAS_REPOS_OPEN2 1
 #define PYSNV_HAS_IO_REMOVE_FILE2 1
-#define PYSVN_HAS_CLIENT_BLAME5 QQQ
-#define PYSVN_HAS_CLIENT_COMMIT5 QQQ
-#define PYSVN_HAS_CLIENT_COPY6 QQQ
-#define PYSVN_HAS_CLIENT_DELETE4 QQQ
-#define PYSVN_HAS_CLIENT_DIFF5 QQQ
-#define PYSVN_HAS_CLIENT_DIFF_PEG5 QQQ
-#define PYSVN_HAS_CLIENT_EXPORT5
+#define PYSVN_HAS_CLIENT_ANNOTATE5 1
+#define PYSVN_HAS_CLIENT_COMMIT5 1
+#define PYSVN_HAS_CLIENT_COPY6 1
+#define PYSVN_HAS_CLIENT_DELETE4 1
+#define PYSVN_HAS_CLIENT_DIFF5 1
+#define PYSVN_HAS_CLIENT_DIFF_PEG5 1
+#define PYSVN_HAS_CLIENT_EXPORT5 QQQ
 #define PYSVN_HAS_CLIENT_GET_WC_ROOT QQQ
 #define PYSVN_HAS_CLIENT_IMPORT4 QQQ
 #define PYSVN_HAS_CLIENT_INFO2_T QQQ
@@ -189,39 +189,59 @@
 #define PYSVN_HAS_CLIENT_INFO_RECEIVER2_T QQQ
 #define PYSVN_HAS_CLIENT_MERGE4 QQQ
 #define PYSVN_HAS_CLIENT_MERGEINFO_LOG QQQ
-#define PYSVN_HAS_CLIENT_MERGE_PEG4 QQQ
+#define PYSVN_HAS_CLIENT_MERGE_PEG4 1
 #define PYSVN_HAS_CLIENT_MIN_MAX_REVISIONS QQQ
-#define PYSVN_HAS_CLIENT_MKDIR4 QQQ
-#define PYSVN_HAS_CLIENT_MOVE6 QQQ
+#define PYSVN_HAS_CLIENT_MKDIR4 1
+#define PYSVN_HAS_CLIENT_MOVE6 1
 #define PYSVN_HAS_CLIENT_PATCH QQQ
 #define PYSVN_HAS_CLIENT_PATCH_FUNC_T QQQ
 #define PYSVN_HAS_CLIENT_PROPGET4 QQQ
-#define PYSVN_HAS_CLIENT_PROPSET_LOCAL QQQ
-#define PYSVN_HAS_CLIENT_PROPSET_REMOTE QQQ
+#define PYSVN_HAS_CLIENT_PROPSET_LOCAL 1
+#define PYSVN_HAS_CLIENT_PROPSET_REMOTE 1
 #define PYSVN_HAS_CLIENT_RELOCATE2 QQQ
-#define PYSVN_HAS_CLIENT_STATUS5 QQQ
-#define PYSVN_HAS_CLIENT_STATUS_T QQQ
-#define PYSVN_HAS_CLIENT_SWITCH3 QQQ
+#define PYSVN_HAS_CLIENT_STATUS5 1
+#define PYSVN_HAS_CLIENT_STATUS_T 1
+#define PYSVN_HAS_CLIENT_SWITCH3 1
 #define PYSVN_HAS_CLIENT_UPDATE4 QQQ
 #define PYSVN_HAS_CLIENT_UPGRADE QQQ
 #define PYSVN_HAS_CLIENT_URL_FROM_PATH2 QQQ
 #define PYSVN_HAS_CLIENT_UUID_FROM_PATH2 QQQ
+#define PYSVN_HAS_FS_CHANGE_REV_PROP2 QQQ
 #endif
 
+// SVN 1.8 or later
 #if (SVN_VER_MAJOR == 1 && SVN_VER_MINOR >= 8) || SVN_VER_MAJOR > 1
 #define PYSVN_HAS_SVN_1_8
-#define PYSVN_HAS_CLIENT_GET_REPOS_ROOT 1
 #define PYSVN_HAS_CLIENT_ADD5 1
+#define PYSVN_HAS_CLIENT_COMMIT6 1
+#define PYSVN_HAS_CLIENT_CLEANUP 1
 #define PYSVN_HAS_CLIENT_CREATE_CONTEXT2 1
+#define PYSVN_HAS_CLIENT_DIFF6 QQQ
+#define PYSVN_HAS_CLIENT_DIFF_PEG6 QQQ
+#define PYSVN_HAS_CLIENT_GET_MERGING_SUMMARY QQQ
+#define PYSVN_HAS_CLIENT_GET_REPOS_ROOT 1
+#define PYSVN_HAS_CLIENT_IMPORT5 QQQ
+#define PYSVN_HAS_CLIENT_LIST3 QQQ
+#define PYSVN_HAS_CLIENT_MERGE5 QQQ
+#define PYSVN_HAS_CLIENT_MERGEINFO_LOG2 QQQ
+#define PYSVN_HAS_CLIENT_MERGE_PEG5 QQQ
+#define PYSVN_HAS_CLIENT_MOVE7 1
+#define PYSVN_HAS_CLIENT_PROPGET5 1
+#define PYSVN_HAS_CLIENT_PROPLIST4 QQQ
 #endif
 
+// SVN 1.9 or later
 #if (SVN_VER_MAJOR == 1 && SVN_VER_MINOR >= 9) || SVN_VER_MAJOR > 1
 #define PYSVN_HAS_SVN_1_9
-#define PYSVN_HAS_CLIENT_VACUUM QQQ
-#define PYSVN_HAS_CLIENT_REVERT3 QQQ
-#define PYSVN_HAS_CLIENT_COPY7 QQQ
-#define PYSVN_HAS_CLIENT_CAT3 QQQ
-#define PYSVN_HAS_CLIENT_INFO4 QQQ
+#define PYSVN_HAS_STREAM_READ_FULL 1
+#define PYSVN_HAS_CLIENT_CAT3 1
+#define PYSVN_HAS_CLIENT_CLEANUP2 1
+#define PYSVN_HAS_CLIENT_COPY7 1
+#define PYSVN_HAS_CLIENT_INFO4 1
+#define PYSVN_HAS_CLIENT_REVERT3 1
+#define PYSVN_HAS_CLIENT_STATUS6 1
+#define PYSVN_HAS_CLIENT_VACUUM 1
+#define PYSVN_HAS_REPOS_OPEN3 1
 #endif
 
 #if defined( PYSVN_HAS_CLIENT_STATUS3 )
@@ -290,6 +310,8 @@ public:
     operator svn_client_ctx_t *();
     svn_client_ctx_t *ctx();
 
+    static SvnContext *castBaton( void *baton_ ) { return static_cast<SvnContext *>( baton_ ); }
+
     // only use this pool for data that has a life time
     // that matches the life time of the context
     apr_pool_t          *getContextPool();
@@ -417,7 +439,7 @@ public:
 private:
     apr_pool_t          *m_pool;
     svn_client_ctx_t    *m_context;
-    char                *m_config_dir;
+    const char          *m_config_dir;
 };
 
 class SvnTransaction
