@@ -1,4 +1,9 @@
-#!/bin/sh
+#!/bin/bash
+#
+#   test-01.sh
+#       test the main commands that are in all versions
+#
+
 # need to get rid of any symbolic links in the WORKDIR
 export WORKDIR=$( ${PYTHON} -c 'import os;os.chdir("..");print( os.getcwd() )' )
 
@@ -101,6 +106,10 @@ cmd_pysvn cat -r head file://${TESTROOT}/repos/trunk/test/file1.txt
 cmd_pysvn cat -r 4 file://${TESTROOT}/repos/trunk/test/file6.txt
 
 echo Info: Testing - cleanup
+cmd_pysvn cleanup ${TESTROOT}/wc1
+cmd cd ${TESTROOT}/wc1
+cmd_pysvn cleanup .
+cmd cd ${TESTROOT}/wc1/test
 
 echo Info: Testing - copy
 cmd_pysvn mkdir file://${TESTROOT}/repos/tags -m "test-01 add tags"
@@ -126,8 +135,6 @@ ${PYTHON} ${WORKDIR}/Tests/find.py ${TESTROOT}/export1.cr
 ${PYTHON} ${WORKDIR}/Tests/find.py ${TESTROOT}/export1.lf
 ${PYTHON} ${WORKDIR}/Tests/find.py ${TESTROOT}/export1.crlf
 
-echo Info: Testing - import
-
 echo Info: Testing - info
 cmd_pysvn info ${TESTROOT}/wc2/test
 cmd_pysvn info ${TESTROOT}/wc2/test/file1.txt
@@ -261,3 +268,20 @@ cmd_pysvn status ${TESTROOT}/wc3/test-branch
 cmd_pysvn diff ${TESTROOT}/wc3/test-branch
 
 cmd ${PYTHON} ${WORKDIR}/Tests/test_01_set_get_tests.py ${TESTROOT}/configdir
+
+echo Info: Testing - import
+echo test import file 1 >"${TMPDIR}/import1.txt"
+echo test import file 2 >"${TMPDIR}/import 2.txt"
+
+cmd_pysvn mkdir "file://${TESTROOT}/root/repos/trunk/test/import" -m "test-01 add import"
+
+cmd_pysvn import --message "no spaces"    "${TMPDIR}/import1.txt" "file://${TESTROOT}/root/repos/trunk/test/import/import-file1.txt"
+cmd_pysvn import --message "space in url" "${TMPDIR}/import1.txt" "file://${TESTROOT}/root/repos/trunk/test/import/import file1A.txt"
+cmd_pysvn import --message "%20 in url"   "${TMPDIR}/import1.txt" "file://${TESTROOT}/root/repos/trunk/test/import/import%20file1B.txt"
+
+cmd_pysvn import --message "space in file, none in url"  "${TMPDIR}/import 2.txt" "file://${TESTROOT}/root/repos/trunk/test/import/import-file2.txt"
+cmd_pysvn import --message "space in file, space in url" "${TMPDIR}/import 2.txt" "file://${TESTROOT}/root/repos/trunk/test/import/import file2A.txt"
+cmd_pysvn import --message "space in file, %20 in url"   "${TMPDIR}/import 2.txt" "file://${TESTROOT}/root/repos/trunk/test/import/import%20file2B.txt"
+
+cmd_pysvn update ${TESTROOT}/wc1
+cmd_pysvn log --limit 6 --verbose ${TESTROOT}/wc1
