@@ -1,4 +1,9 @@
-#!/bin/sh
+#!/bin/bash
+#
+#   test-05.sh
+#       test info2 with locked files
+#
+
 # need to get rid of any symbolic links in the WORKDIR
 export WORKDIR=$( ${PYTHON} -c 'import os;os.chdir("..");print( os.getcwd() )' )
 
@@ -57,8 +62,12 @@ cmd_pysvn status --verbose ${TESTROOT}/wc1
 echo Info: Test - info2 of unlocked files
 cmd_pysvn info2 ${TESTROOT}/wc1/test/file1.txt
 
+echo Info: Test - list of unlocked files
+cmd_pysvn list --verbose --fetch-locks ${TESTROOT}/wc1/test/file1.txt
+cmd_pysvn list --verbose --fetch-locks ${TESTROOT}/wc1/test
+
 echo Info: Test - lock unlocked file
-cmd_pysvn lock ${TESTROOT}/wc1/test/file1.txt
+cmd_pysvn lock ${TESTROOT}/wc1/test/file1.txt -m "lock comment test 05"
 
 echo Info: Test - status of locked files
 cmd_pysvn status --verbose ${TESTROOT}/wc1
@@ -66,6 +75,10 @@ cmd_pysvn status --verbose ${TESTROOT}/wc1
 echo Info: Test - info2 of locked files
 cmd_pysvn info2 ${TESTROOT}/wc1/test/file1.txt
 
+echo Info: Test - list of locked files
+cmd_pysvn list --verbose --fetch-locks ${TESTROOT}/wc1/test/file1.txt
+cmd_pysvn list --verbose --fetch-locks ${TESTROOT}/wc1/test
+
 echo Info: Test - attempt to checkin over a locked file
 cmd cd ${TESTROOT}/wc2/test
 echo Change to file 1 >>file1.txt
@@ -90,15 +103,24 @@ cmd_pysvn commit -m "change when file locked in this wc" .
 echo Info: Test - status of locked files
 cmd_pysvn status --verbose ${TESTROOT}/wc2
 
+echo Info: Test - list of locked files
+cmd_pysvn list --verbose --fetch-locks --recursive ${TESTROOT}/wc2
+
 echo Info: Test - unlock locked file
 cmd_pysvn unlock ${TESTROOT}/wc2/test/file1.txt
 
-echo Info: Test - status of locked files
+echo Info: Test - status of unlocked files
 cmd_pysvn status --verbose ${TESTROOT}/wc2
 
+echo Info: Test - list of unlocked files
+cmd_pysvn list --verbose --fetch-locks --recursive ${TESTROOT}/wc2
+
 echo Info: Test - status of locked files
 cmd_pysvn status --verbose ${TESTROOT}/wc1
 
+echo Info: Test - list of unlocked files
+cmd_pysvn list --verbose --fetch-locks --recursive ${TESTROOT}/wc1
+
 echo Info: Test - update with stolen lock
 cmd_pysvn update ${TESTROOT}/wc1/test
 
@@ -108,4 +130,7 @@ cmd_pysvn status --verbose ${TESTROOT}/wc1
 echo Info: Test - info2 of URL
 cmd_pysvn info2 --revision HEAD file://${TESTROOT}/repos/trunk/test/file1.txt
 
+echo Info: Test - list of locked files
+cmd_pysvn list --verbose --fetch-locks --recursive ${TESTROOT}/wc1
+
 true
